/*
 * Copyright (c) 2013, Olivier MATZ <zer0@droids-corp.org>
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <aversive.h>
#include <aversive/queue.h>

#include <stdint.h>

#include <uart.h>

#include <scheduler.h>
#include <clock_time.h>
#include <parse.h>
#include <rdline.h>
#include <timer.h>

#include "xbee_proto.h"
#include "callout.h"
#include "rc_proto.h"
#include "main.h"

struct power_levels {
	int ttl;
	int power_db;
};

struct power_levels power_levels[MAX_POWER_LEVEL];

static int set_power_level(void *frame, unsigned len, void *arg)
{
	struct xbee_atresp_hdr *atresp = (struct xbee_atresp_hdr *)frame;
	int level = (intptr_t)arg;
	uint8_t db;

	/* XXX check if this test is correct */
	if (len < sizeof(struct xbee_atresp_hdr) + sizeof(uint8_t))
		return -1;

	db = atresp->data[0];
	power_levels[level].power_db = db;
	power_levels[level].ttl = 2;
	return 0;
}

void rc_proto_rx_range(int power_level)
{
	xbeeapp_send_atcmd("DB", NULL, 0, 0,
			   set_power_level, (void *)(intptr_t)power_level);

}


